/// Implements the most common use case for states.
///
/// Value is available -> [ValueState]
/// Loading the value -> [LoadingState]
/// An error occurred -> [UnavailableState]
///
/// See [PropertyBuilder] for more.
abstract class PropertyState<T> {}

class ValueState<T> extends PropertyState<T> {
  final T value;

  ValueState(this.value);
}

class LoadingState<T> extends PropertyState<T> {}

class UnavailableState<T> extends PropertyState<T> {
  final dynamic error;

  bool get isError => error != null;

  UnavailableState({this.error});
}
